@@ -77,7 +77,6 @@ class SAS:
 @dataclass
 class FoldXSAS:
     sas: SAS
-    in_structure: bool
     dd_g: float
 
 
@@ -105,20 +104,12 @@ class Pocket:
     residues: Optional[List[Residue]] = None
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass
-class Catalytic:
-    uniprot_positions: List[int]
-    residues: Optional[List[Residue]] = None
-
-
 @dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass
 class Binding:
     duration: int
     error: Optional[str] = None
     pockets: Optional[List[Pocket]] = None
-    catalytic: Optional[Catalytic] = None
     ligands: Optional[Dict[str, List[Residue]]] = None
 
 
